# Generated by Django 2.1.5 on 2019-02-20 22:52

import datetime
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import ls.joyous.fields
import ls.joyous.models.events
import timezone_field.fields
import wagtail.core.fields


class Migration(migrations.Migration):

    dependencies = [
        ('joyous', '0012_auto_20181231_1827'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='calendarpage',
            options={'verbose_name': 'multiday event page', 'verbose_name_plural': 'multiday event pages'},
        ),
        migrations.AlterModelOptions(
            name='cancellationpage',
            options={'default_manager_name': 'objects', 'verbose_name': 'cancellation', 'verbose_name_plural': 'cancellations'},
        ),
        migrations.AlterModelOptions(
            name='eventcategory',
            options={'ordering': ['name'], 'verbose_name': 'event category', 'verbose_name_plural': 'event categories'},
        ),
        migrations.AlterModelOptions(
            name='extrainfopage',
            options={'default_manager_name': 'objects', 'verbose_name': 'extra event information', 'verbose_name_plural': 'extra event information'},
        ),
        migrations.AlterModelOptions(
            name='multidayeventpage',
            options={'default_manager_name': 'objects', 'verbose_name': 'multiday event page', 'verbose_name_plural': 'multiday event pages'},
        ),
        migrations.AlterModelOptions(
            name='multidayrecurringeventpage',
            options={'verbose_name': 'multiday recurring event page', 'verbose_name_plural': 'multiday recurring event pages'},
        ),
        migrations.AlterModelOptions(
            name='postponementpage',
            options={'default_manager_name': 'objects', 'verbose_name': 'postponement', 'verbose_name_plural': 'postponements'},
        ),
        migrations.AlterModelOptions(
            name='recurringeventpage',
            options={'default_manager_name': 'objects', 'verbose_name': 'recurring event page', 'verbose_name_plural': 'recurring event pages'},
        ),
        migrations.AlterModelOptions(
            name='simpleeventpage',
            options={'default_manager_name': 'objects', 'verbose_name': 'event page', 'verbose_name_plural': 'event pages'},
        ),
        migrations.AlterField(
            model_name='calendarpage',
            name='default_view',
            field=models.CharField(choices=[('L', 'List View'), ('W', 'Weekly View'), ('M', 'Monthly View')], default='M', max_length=15, verbose_name='default view'),
        ),
        migrations.AlterField(
            model_name='calendarpage',
            name='intro',
            field=wagtail.core.fields.RichTextField(blank=True, verbose_name='intro'),
        ),
        migrations.AlterField(
            model_name='calendarpage',
            name='view_choices',
            field=ls.joyous.fields.MultipleSelectField(blank=True, choices=[('L', 'List View'), ('W', 'Weekly View'), ('M', 'Monthly View')], default=['L', 'W', 'M'], verbose_name='view choices'),
        ),
        migrations.AlterField(
            model_name='cancellationpage',
            name='cancellation_details',
            field=wagtail.core.fields.RichTextField(blank=True, help_text='Why was the event cancelled?', verbose_name='details'),
        ),
        migrations.AlterField(
            model_name='cancellationpage',
            name='cancellation_title',
            field=models.CharField(blank=True, help_text='Show in place of cancelled event (Leave empty to show nothing)', max_length=255, verbose_name='title'),
        ),
        migrations.AlterField(
            model_name='cancellationpage',
            name='overrides',
            field=models.ForeignKey(help_text='The recurring event that we are updating.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='joyous.RecurringEventPage', verbose_name='overrides'),
        ),
        migrations.AlterField(
            model_name='eventcategory',
            name='code',
            field=models.CharField(max_length=4, unique=True, verbose_name='code'),
        ),
        migrations.AlterField(
            model_name='eventcategory',
            name='name',
            field=models.CharField(max_length=80, verbose_name='name'),
        ),
        migrations.AlterField(
            model_name='extrainfopage',
            name='extra_information',
            field=wagtail.core.fields.RichTextField(help_text='Information just for this date', verbose_name='extra information'),
        ),
        migrations.AlterField(
            model_name='extrainfopage',
            name='extra_title',
            field=models.CharField(blank=True, help_text='A more specific title for this occurence (optional)', max_length=255, verbose_name='title'),
        ),
        migrations.AlterField(
            model_name='extrainfopage',
            name='overrides',
            field=models.ForeignKey(help_text='The recurring event that we are updating.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='joyous.RecurringEventPage', verbose_name='overrides'),
        ),
        migrations.AlterField(
            model_name='grouppage',
            name='content',
            field=wagtail.core.fields.RichTextField(blank=True, default='', help_text='An area of text for whatever you like', verbose_name='content'),
        ),
        migrations.AlterField(
            model_name='multidayeventpage',
            name='category',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='joyous.EventCategory', verbose_name='category'),
        ),
        migrations.AlterField(
            model_name='multidayeventpage',
            name='date_from',
            field=models.DateField(default=datetime.date.today, verbose_name='start date'),
        ),
        migrations.AlterField(
            model_name='multidayeventpage',
            name='date_to',
            field=models.DateField(default=datetime.date.today, verbose_name='end date'),
        ),
        migrations.AlterField(
            model_name='multidayeventpage',
            name='details',
            field=wagtail.core.fields.RichTextField(blank=True, verbose_name='details'),
        ),
        migrations.AlterField(
            model_name='multidayeventpage',
            name='group_page',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='joyous.GroupPage', verbose_name='group page'),
        ),
        migrations.AlterField(
            model_name='multidayeventpage',
            name='image',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image', verbose_name='image'),
        ),
        migrations.AlterField(
            model_name='multidayeventpage',
            name='location',
            field=models.CharField(blank=True, max_length=255, verbose_name='location'),
        ),
        migrations.AlterField(
            model_name='multidayeventpage',
            name='time_from',
            field=models.TimeField(blank=True, null=True, verbose_name='start time'),
        ),
        migrations.AlterField(
            model_name='multidayeventpage',
            name='time_to',
            field=models.TimeField(blank=True, null=True, verbose_name='end time'),
        ),
        migrations.AlterField(
            model_name='multidayeventpage',
            name='tz',
            field=timezone_field.fields.TimeZoneField(default=ls.joyous.models.events._get_default_timezone, verbose_name='time zone'),
        ),
        migrations.AlterField(
            model_name='multidayeventpage',
            name='website',
            field=models.URLField(blank=True, verbose_name='website'),
        ),
        migrations.AlterField(
            model_name='postponementpage',
            name='category',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='joyous.EventCategory', verbose_name='category'),
        ),
        migrations.AlterField(
            model_name='postponementpage',
            name='date',
            field=models.DateField(verbose_name='date'),
        ),
        migrations.AlterField(
            model_name='postponementpage',
            name='details',
            field=wagtail.core.fields.RichTextField(blank=True, verbose_name='details'),
        ),
        migrations.AlterField(
            model_name='postponementpage',
            name='group_page',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='joyous.GroupPage', verbose_name='group page'),
        ),
        migrations.AlterField(
            model_name='postponementpage',
            name='image',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image', verbose_name='image'),
        ),
        migrations.AlterField(
            model_name='postponementpage',
            name='location',
            field=models.CharField(blank=True, max_length=255, verbose_name='location'),
        ),
        migrations.AlterField(
            model_name='postponementpage',
            name='postponement_title',
            field=models.CharField(help_text='The title for the postponed event', max_length=255, verbose_name='title'),
        ),
        migrations.AlterField(
            model_name='postponementpage',
            name='time_from',
            field=models.TimeField(blank=True, null=True, verbose_name='start time'),
        ),
        migrations.AlterField(
            model_name='postponementpage',
            name='time_to',
            field=models.TimeField(blank=True, null=True, verbose_name='end time'),
        ),
        migrations.AlterField(
            model_name='postponementpage',
            name='website',
            field=models.URLField(blank=True, verbose_name='website'),
        ),
        migrations.AlterField(
            model_name='recurringeventpage',
            name='category',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='joyous.EventCategory', verbose_name='category'),
        ),
        migrations.AlterField(
            model_name='recurringeventpage',
            name='details',
            field=wagtail.core.fields.RichTextField(blank=True, verbose_name='details'),
        ),
        migrations.AlterField(
            model_name='recurringeventpage',
            name='group_page',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='joyous.GroupPage', verbose_name='group page'),
        ),
        migrations.AlterField(
            model_name='recurringeventpage',
            name='image',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image', verbose_name='image'),
        ),
        migrations.AlterField(
            model_name='recurringeventpage',
            name='location',
            field=models.CharField(blank=True, max_length=255, verbose_name='location'),
        ),
        migrations.AlterField(
            model_name='recurringeventpage',
            name='num_days',
            field=models.IntegerField(default=1, validators=[django.core.validators.MinValueValidator(1), django.core.validators.MaxValueValidator(99)], verbose_name='number of days'),
        ),
        migrations.AlterField(
            model_name='recurringeventpage',
            name='repeat',
            field=ls.joyous.fields.RecurrenceField(verbose_name='repeat'),
        ),
        migrations.AlterField(
            model_name='recurringeventpage',
            name='time_from',
            field=models.TimeField(blank=True, null=True, verbose_name='start time'),
        ),
        migrations.AlterField(
            model_name='recurringeventpage',
            name='time_to',
            field=models.TimeField(blank=True, null=True, verbose_name='end time'),
        ),
        migrations.AlterField(
            model_name='recurringeventpage',
            name='tz',
            field=timezone_field.fields.TimeZoneField(default=ls.joyous.models.events._get_default_timezone, verbose_name='time zone'),
        ),
        migrations.AlterField(
            model_name='recurringeventpage',
            name='website',
            field=models.URLField(blank=True, verbose_name='website'),
        ),
        migrations.AlterField(
            model_name='simpleeventpage',
            name='category',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='joyous.EventCategory', verbose_name='category'),
        ),
        migrations.AlterField(
            model_name='simpleeventpage',
            name='date',
            field=models.DateField(default=datetime.date.today, verbose_name='date'),
        ),
        migrations.AlterField(
            model_name='simpleeventpage',
            name='details',
            field=wagtail.core.fields.RichTextField(blank=True, verbose_name='details'),
        ),
        migrations.AlterField(
            model_name='simpleeventpage',
            name='group_page',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='joyous.GroupPage', verbose_name='group page'),
        ),
        migrations.AlterField(
            model_name='simpleeventpage',
            name='image',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image', verbose_name='image'),
        ),
        migrations.AlterField(
            model_name='simpleeventpage',
            name='location',
            field=models.CharField(blank=True, max_length=255, verbose_name='location'),
        ),
        migrations.AlterField(
            model_name='simpleeventpage',
            name='time_from',
            field=models.TimeField(blank=True, null=True, verbose_name='start time'),
        ),
        migrations.AlterField(
            model_name='simpleeventpage',
            name='time_to',
            field=models.TimeField(blank=True, null=True, verbose_name='end time'),
        ),
        migrations.AlterField(
            model_name='simpleeventpage',
            name='tz',
            field=timezone_field.fields.TimeZoneField(default=ls.joyous.models.events._get_default_timezone, verbose_name='time zone'),
        ),
        migrations.AlterField(
            model_name='simpleeventpage',
            name='website',
            field=models.URLField(blank=True, verbose_name='website'),
        ),
    ]
