{% extends "joyous/exception_base.html" %}
{% load wagtailimages_tags %}

{% block event_title %}
  <div class="joy-title joy-title--page">
    {# postponement_title is required #}
    <h1>{{ page.postponement_title }}</h1>
  </div>
{% endblock %}
